@@ -1,5 +1,4 @@
 from itertools import chain, batched
-
 from typing import List, Dict, Any
 
 from fmtr.tools.datatype_tools import is_none
@@ -73,3 +72,12 @@ def dedupe(items):
 
     """
     return list(dict.fromkeys(items))
+
+
+def get_class_lookup(*classes, name_function=lambda cls: cls.__name__):
+    """
+
+    Dictionary of class names to classes
+
+    """
+    return {name_function(cls): cls for cls in classes}
