@@ -4,5 +4,5 @@ from fmtr.tools.setup_tools.setup_tools import Setup, SetupPaths, Dependencies,
 
 try:
     from setuptools import find_namespace_packages, find_packages, setup as setup_setuptools
-except ImportError as exception:
+except ModuleNotFoundError as exception:
     find_namespace_packages = find_packages = setup_setuptools = MissingExtraMockModule('setup', exception)
